Arguments
X
Matrix or data frame of numeric data containing the responses of nrow(X) respondents to ncol(X) items.
Each row is called an observation.
Each item has $m+1$ response options $0, \ldots, m$. Other
B
Integer giving the number of Forward Searches with different initial subsamples.
cutoff
Integer, the first step of the Forward Search for which the number of unique subsamples is below the cutoff equals $n1$.
initial.subsample.size
Integer giving the size of the initial subsample.
By default initial.subsample.size equals the minimum of the number of restscore groups over all items multiplied by the number of items.
minsize
Integer giving the minimum size of a rest score group. By default
minsize = $N/10$ if $N \ge 500$;
minsize = $N/5$ if $250 \le N < 500$; and
minsize = max$(N/3,50)$ if $N < 250$
seed
Numeric; fixes the random number generation set.seed in order to control the initial subsample.
Default is a randomly drawn value between 1 and 10000.
verbose
Logical, indicating whether B should be printed on the screen. If FALSE, no output is produced. The default is TRUE.